# tnp
the north pipe.

# summary
Practical pipelining on GCP.

# install
    pip install tnp

# develop
to release make a tag like v0.1.0 that matches package version.

    python3 setup.py sdist
    python3 -m twine upload dist/*
